@@ -2,7 +2,7 @@
 #
 #   file: lib/Dist/Zilla/Role/TextTemplater.pm
 #
-#   Copyright © 2015, 2016 Van de Bugger.
+#   Copyright © 2015, 2016, 2018 Van de Bugger.
 #
 #   This file is part of perl-Dist-Zilla-Role-TextTemplater.
 #
@@ -17,6 +17,8 @@
 #   You should have received a copy of the GNU General Public License along with
 #   perl-Dist-Zilla-Role-TextTemplater. If not, see <http://www.gnu.org/licenses/>.
 #
+#   SPDX-License-Identifier: GPL-3.0-or-later
+#
 #   ---------------------------------------------------------------------- copyright and license ---
 
 #pod =for :this This is C<Dist::Zilla::Role::TextTemplater> module documentation. Read this if you want to
@@ -67,7 +69,7 @@ use namespace::autoclean;
 use version 0.77;
 
 # ABSTRACT: Have text templating capabilities in your Dist::Zilla plugin
-our $VERSION = 'v0.8.6'; # VERSION
+our $VERSION = 'v0.8.7'; # VERSION
 
 with 'Dist::Zilla::Role::ErrorLogger' => { -version => 'v0.6.0' };  # Need `log_errors_in_file`.
 
@@ -75,7 +77,8 @@ use Carp qw{ croak };
 use Dist::Zilla::File::InMemory;
 use Dist::Zilla::File::OnDisk;
 use List::Util qw{ min max };
-use Text::Template qw{};
+use Text::Template qw{};            ## REQUIRE: Text::Template != 1.48, != 1.49
+    # See <https://github.com/mschout/perl-text-template/issues/8>.
 
 # --------------------------------------------------------------------------------------------------
 
@@ -440,7 +443,7 @@ sub tt_fill_in {
                     chomp( $msg );
                     $self->log( $msg );
                 };
-                $result = $tt->fill_in( %args, package => "$package" );
+                $result = $tt->fill_in( %args, package => "$package", filename => $file->name );
             }
             #   `Text::Template` doc says:
             #       If the `BROKEN` function returns undef, `Text::Template` will immediately abort
@@ -705,7 +708,7 @@ sub fill_in_file {
 #pod
 #pod =head1 COPYRIGHT AND LICENSE
 #pod
-#pod Copyright (C) 2015, 2016 Van de Bugger
+#pod Copyright (C) 2015, 2016, 2018 Van de Bugger
 #pod
 #pod License GPLv3+: The GNU General Public License version 3 or later
 #pod <http://www.gnu.org/licenses/gpl-3.0.txt>.
@@ -889,7 +892,7 @@ Dist::Zilla::Role::TextTemplater - Have text templating capabilities in your Dis
 
 =head1 VERSION
 
-Version v0.8.6, released on 2016-11-18 20:03 UTC.
+Version v0.8.7, released on 2018-02-27 21:17 UTC.
 
 =head1 WHAT?
 
@@ -1348,7 +1351,7 @@ Van de Bugger <van.de.bugger@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2015, 2016 Van de Bugger
+Copyright (C) 2015, 2016, 2018 Van de Bugger
 
 License GPLv3+: The GNU General Public License version 3 or later
 <http://www.gnu.org/licenses/gpl-3.0.txt>.
